import { NextApiHandler } from 'next';
import { ExpressLikeRouter } from './express-like-router.js';
import { R as RouterBuilderOptions } from './error-handler-e49dcd2f.js';
import './api-logger.js';
import './constants.js';

/**
 * A router builder is next api handler builder that exposes express-like api.
 *
 * ### Example (basic usage)
 * ```js
 * // In next.js /pages/api/[route]
 * import { RouterBuilder } from 'next-api-handler'
 * const router = new RouterBuilder().build()
 * export default router
 * ```
 *
 * ### Example (add RESTful method)
 * ```js
 * import { RouterBuilder } from 'next-api-handler'
 * const router = new RouterBuilder().get((req, res) => "RESPONSE")
 * export default router
 * ```
 *
 * ### Example (add async method)
 * ```js
 * import { RouterBuilder } from 'next-api-handler'
 * const handler = new RouterBuilder().get(async (req, res) => "ASYNC RESPONSE")
 * export default router
 * ```
 *
 * @returns a builder that can build a next.js api handler.
 */
declare class RouterBuilder extends ExpressLikeRouter {
    private readonly routerOptions;
    private readonly logger;
    constructor(options?: RouterBuilderOptions);
    build(): NextApiHandler;
    private applyErrorHandler;
    private resolveMiddlewareListAndQueue;
    private getMiddlewarePromiseList;
    private resolveMiddlewareQueue;
}

export { RouterBuilder };
